@@ -12,6 +12,9 @@ class Experiment:
     Experiment -> trials -> runs.
     """
 
+    CONFIG_FILE = "config.json"
+    RUN_DIR_REGEX = r"run\d+$"
+
     def __init__(self, config_iterator, logdir, name=None, description=None):
         self.config_iterator = config_iterator
         self.logdir = logdir
@@ -21,18 +24,23 @@ class Experiment:
     def start(self):
         config_files = self.config_iterator.dump(self.logdir)
 
-    def run(self, exec_func, num_samples, num_workers=None):
+    def run(self, exec_func, num_samples, num_workers=None, verbose=False):
         """
         Executes the trial runner function a given number of times.
 
         Args:
-            exec_func (Callable[Dict] -> Result): The trial runner function (e.g., exec_func(config, logdir)).
+            exec_func (Callable[Dict] -> Result): The trial runner function.
             num_samples (int): The number of runs per trial.
             num_workers (int): The number of worker processes.
         """
         results = {}
 
-        for config in self.config_iterator:
+        total_num_trials = len(self.config_iterator)
+
+        for i, config in enumerate(self.config_iterator):
+            if verbose:
+                print(f">> Trial #{i}/{total_num_trials} : {config}")
+
             trial_id, trial_dir = self._get_trial(config)
 
             range_num_samples = self._get_run_ids(trial_dir, num_samples)
@@ -56,39 +64,28 @@ class Experiment:
 
         return results
 
-    def report_mean_std(self, metric, extension="csv"):
-        results = {}
-
-        for config in self.config_iterator:
-            trial_id, trial_dir = self._get_trial(config)
-
-            data = []
-            for run in self._get_run_dirs(trial_dir):
-                filepath = os.path.join(trial_dir, run, f"{metric}.{extension}")
-                if os.path.isfile(filepath):
-                    data.append(pd.read_csv(filepath))
-
-            if data:
-                data = pd.concat(data)
-                data = data.groupby(data.index, sort=False)
-                results[trial_id] = (data.mean(), data.std())
-
-        return results
-
     def _get_trial(self, config):
         trial_id = self.config_iterator._trial_id(config)
         trial_dir = os.path.join(self.logdir, trial_id)
         return trial_id, trial_dir
 
     @classmethod
-    def _get_run_dirs(cls, trial_dir):
+    def get_run_dirs(cls, trial_dir):
         return [
-            path for path in os.listdir(trial_dir)
-            if re.search(r"run\d+$", path)
+            f.path for f in os.scandir(trial_dir)
+            if re.search(cls.RUN_DIR_REGEX, f.path)
         ]
 
     @classmethod
     def _get_run_ids(cls, trial_dir, num_samples):
-        previous_run_dirs = cls._get_run_dirs(trial_dir)
+        previous_run_dirs = cls.get_run_dirs(trial_dir)
         start_id = len(previous_run_dirs)
         return range(start_id, start_id + num_samples)
+
+    @classmethod
+    def is_run_dir(cls, basename):
+        return re.search(cls.RUN_DIR_REGEX, basename)
+
+    @classmethod
+    def is_trial_dir(cls, dirname):
+        return cls.CONFIG_FILE in os.listdir(dirname)
